(***********************************************************************)
(*                                                                     *)
(*                              Ref-indic                              *)
(*                                                                     *)
(*                        Refinement indicators                        *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright (c) 2013-2014 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* Beginning of OCamlGen, 3.3+dev4 generated code *)

open Refinement_types_print;;

let rec print_length ppf = function
  | u_l -> Upervasives_print.print_length ppf u_l

and print_width ppf = function | l -> print_length ppf l

and print_height ppf = function | l -> print_length ppf l

and print_size ppf = function
  | (w, h) ->
    Format.fprintf ppf "%,@[<1>(@,"; print_width ppf w;
    Format.fprintf ppf "%,,@ "; print_height ppf h;
    Format.fprintf ppf "%,@,)@]"
;;

let print_color ppf = function | c_t -> Colors_print.print_t ppf c_t
;;

let print_aspect ppf = function
  | Display_types.Portrait -> Format.fprintf ppf "%s" "Portrait"
  | Display_types.Landscape -> Format.fprintf ppf "%s" "Landscape"
;;

let print_direction ppf = function
  | Display_types.Horizontal_dir -> Format.fprintf ppf "%s" "Horizontal_dir"
  | Display_types.Vertical_dir -> Format.fprintf ppf "%s" "Vertical_dir"
;;

let print_comps_direction ppf = function
  | Display_types.Horizontal_comps_dir ->
    Format.fprintf ppf "%s" "Horizontal_comps_dir"
  | Display_types.Vertical_comps_dir ->
    Format.fprintf ppf "%s" "Vertical_comps_dir"
;;

let rec print_image_size ppf = function | s -> print_size ppf s

and print_display_image_size ppf = function | s -> print_size ppf s

and print_window_size ppf = function | s -> print_size ppf s

and print_min_window_size ppf = function | w -> print_window_size ppf w

and print_max_window_size ppf = function | w -> print_window_size ppf w
;;

let print_scaling_factor ppf = function
  | u_t -> Upositive_rational_print.print_t ppf u_t
;;

let print_scaling ppf = function
  | f_u_t_u_t ->
    Lib_print.print_fun Unatural_print.print_t Unatural_print.print_t ppf
     f_u_t_u_t
;;

let print_graphics_elements ppf = function
  | {
      Display_types.comps_direction = c;
      Display_types.scaling_factor = s;
      Display_types.display_image_size = d;
      Display_types.window_size = w;
    } ->
    Format.fprintf ppf "%,@[<1>{@,";
    Format.fprintf ppf "%,@[<1>comps_direction =@ ";
    print_comps_direction ppf c; Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>scaling_factor =@ ";
    print_scaling_factor ppf s; Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>display_image_size =@ ";
    print_display_image_size ppf d; Format.fprintf ppf "%,;@]@ ";
    Format.fprintf ppf "%,@[<1>window_size =@ "; print_window_size ppf w;
    Format.fprintf ppf "%,;@]@ "; Format.fprintf ppf "%,@,}@]"
;;

let print_quantity ppf = function
  | Display_types.Param -> Format.fprintf ppf "%s" "Param"
  | Display_types.Grad -> Format.fprintf ppf "%s" "Grad"
;;

let print_pixmap_iter pp_a ppf = function
  | f_f_z_f_a_s_u_f_a_p_u ->
    Lib_print.print_fun
     (Lib_print.print_fun print_zone_number
       (Lib_print.print_fun (print_sub_parameter pp_a) Lib_print.print_unit)
     ) (Lib_print.print_fun (print_partition pp_a) Lib_print.print_unit) ppf
     f_f_z_f_a_s_u_f_a_p_u

and print_colormap pp_a ppf = function
  | f_a_c -> Lib_print.print_fun pp_a print_color ppf f_a_c
;;

let print_pixmap ppf = function
  | g_p -> Generic_image_print.print_pixmap ppf g_p

and print_lower_left_corner ppf = function | p -> print_point ppf p
;;

let print_print_pixmap ppf = function
  | f_f_f_u ->
    Lib_print.print_fun Format_print.print_formatter Lib_print.print_unit ppf
     f_f_f_u

and print_alter_pixmap pp_a ppf = function
  | f_a_p_f_a_c_f_a_p_u ->
    Lib_print.print_fun (print_pixmap_iter pp_a)
     (Lib_print.print_fun (print_colormap pp_a)
       (Lib_print.print_fun (print_partition pp_a) Lib_print.print_unit)
     ) ppf f_a_p_f_a_c_f_a_p_u

and print_draw_pixmap ppf = function
  | f_u_u ->
    Lib_print.print_fun Lib_print.print_unit Lib_print.print_unit ppf f_u_u
;;

(* End of OCamlGen, 3.3+dev4 generated code *)
