CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C                            Pio (Fortran)                            C
C                                                                     C
C                    Polyglot Input/Output Library                    C
C                                                                     C
C               EPI Pomdapi, INRIA Paris - Rocquencourt               C
C                                                                     C
C  Copyright 2005-2014 INRIA.                                         C
C  Institut National de Recherche en Informatique et en Automatique.  C
C  All rights reserved. This file is distributed only by permission.  C
C                                                                     C
C  Francois Clement <Francois.Clement@inria.fr>                       C
C  Pierre Weis <Pierre.Weis@inria.fr>                                 C
C  Hend Ben Ameur <hbenameur@yahoo.ca>                                C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

C     $Id: pio_user_error.fpp,v 1.5 2014/05/22 10:16:02 fclement Exp $

#include "pio_user_constants.h"

      subroutine pio_user_set_message_prefix(len, msg)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Input variables.
      character msg*(*)
      integer len
      
      mp_len = min(len, PIO_USER_MAX_MESSAGE_PREFIX_LENGTH)
      msg_prefix(1:mp_len) = msg(1:mp_len)
      
      return
      end


      subroutine pio_user_write_and_send_error_message
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Local variable.
      integer mp_len1, em_len1, max_em_len
      
      write(PIO_USER_DEBUG, *)
     +     msg_prefix(1:mp_len), error_msg(1:em_len)
      
      max_em_len = PIO_USER_MAX_ERROR_MESSAGE_LENGTH
      mp_len1 = min(mp_len, max_em_len)
      em_len1 = min(mp_len1 + em_len, max_em_len) - mp_len1
      em_len = mp_len1 + em_len1
      
      write(error_msg, '(a, a)')
     +     msg_prefix(1:mp_len1), error_msg(1:em_len1)
      
      call pio_init_out_communication(PIO_ERROR, 2)
      
      call pio_add_int(ier)
      call pio_add_string(em_len, error_msg)
      
      call pio_send_out_communication(PIO_STDOUT)
      
      return
      end


      subroutine pio_user_error_open_failure(s_len, sbr, len, fname)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Input arguments.
      character sbr*(*), fname*(*)
      integer s_len, len
      
      ier = PIO_USER_OPEN_FAILURE_ERROR
      
      em_len = 15 + s_len + 1 + 23 + len + 2
      em_len = min(em_len, PIO_USER_MAX_ERROR_MESSAGE_LENGTH)
      
      write(error_msg, 1001) sbr(1:s_len), fname(1:len)
      
 1001 format('fatal error in ', a, ':',
     +     ' open failure on file "', a, '".')
      
      return
      end


      subroutine pio_user_error_unbound_communication(s_len, sbr, tc)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Input arguments.
      character sbr*(*)
      integer s_len, tc
      
      ier = PIO_USER_UNBOUND_COMMUNICATION_ERROR
      
      em_len = 15 + s_len + 1 + 23 + 1 + 1
      em_len = min(em_len, PIO_USER_MAX_ERROR_MESSAGE_LENGTH)
      
      write(error_msg, 1001) sbr(1:s_len), tc
      
 1001 format('fatal error in ', a, ':',
     +     ' unbound communication ', i1, '.')
      
      return
      end


      subroutine pio_user_error_unbound_service_communication
     +     (s_len, sbr, tsc)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Input arguments.
      character sbr*(*)
      integer s_len, tsc
      
      ier = PIO_USER_UNBOUND_SERVICE_COMMUNICATION_ERROR
      
      em_len = 15 + s_len + 1 + 31 + 1 + 1
      em_len = min(em_len, PIO_USER_MAX_ERROR_MESSAGE_LENGTH)
      
      write(error_msg, 1001) sbr(1:s_len), tsc
      
 1001 format('fatal error in ', a, ':',
     +     ' unbound service communication ', i1, '.')
      
      return
      end


      subroutine pio_user_error_unbound_task(s_len, sbr, len, tname)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Input arguments.
      character sbr*(*), tname*(*)
      integer s_len, len
      
      ier = PIO_USER_UNBOUND_TASK_ERROR
      
      em_len = 15 + s_len + 1 + 15 + len + 2
      em_len = min(em_len, PIO_USER_MAX_ERROR_MESSAGE_LENGTH)
      
      write(error_msg, 1001) sbr(1:s_len), tname(1:len)
      
 1001 format('fatal error in ', a, ':',
     +     ' unbound task "', a, '".')
      
      return
      end


      subroutine pio_user_error_wrong_communication
     +     (s_len, sbr, len, msg)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Input arguments.
      character sbr*(*), msg*(*)
      integer s_len, len
      
      ier = PIO_USER_WRONG_COMMUNICATION_ERROR
      
      em_len = 15 + s_len + 1 + 23 + len + 2
      em_len = min(em_len, PIO_USER_MAX_ERROR_MESSAGE_LENGTH)
      
      write(error_msg, 1001) sbr(1:s_len), msg(1:len)
      
 1001 format('fatal error in ', a, ':',
     +     ' wrong communication "', a, '".')
      
      return
      end


      subroutine pio_user_error_wrong_number_of_values
     +     (s_len, sbr, good, bad)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Input arguments.
      character sbr*(*)
      integer s_len, good, bad
      
      ier = PIO_USER_WRONG_NUMBER_OF_VALUES_ERROR
      
      em_len = 15 + s_len + 1 + 13 + 2 + 10 + 11 + 2 + 10
      em_len = min(em_len, PIO_USER_MAX_ERROR_MESSAGE_LENGTH)
      
      write(error_msg, 1001) sbr(1:s_len), good, bad
      
 1001 format('fatal error in ', a, ':',
     +     ' waiting for ', i2, ' value(s),'
     +     ' but found ', i2, ' value(s).')
      
      return
      end


      subroutine pio_user_error_not_initialized(s_len, sbr)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Input arguments.
      character sbr*(*)
      integer s_len
      
      ier = PIO_USER_NOT_INITIALIZED_ERROR
      
      em_len = 15 + s_len + 1 + 17
      em_len = min(em_len, PIO_USER_MAX_ERROR_MESSAGE_LENGTH)
      
      write(error_msg, 1001) sbr(1:s_len)
      
 1001 format('fatal error in ', a, ':',
     +     ' not initialized.')
      
      return
      end


      subroutine pio_user_error_task_computation
     +     (s_len, sbr, t_len, tname, len, msg)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Input arguments.
      character sbr*(*), tname*(*), msg*(*)
      integer s_len, t_len, len
      
      ier = PIO_USER_TASK_COMPUTATION_ERROR
      
      em_len = 15 + s_len + 1 + 7 + t_len + 4 + len + 2
      em_len = min(em_len, PIO_USER_MAX_ERROR_MESSAGE_LENGTH)
      
      write(error_msg, 1001) sbr(1:s_len), tname(1:t_len), msg(1:len)
      
 1001 format('fatal error in ', a, ':',
     +     ' task "', a, '": "', a, '".')
      
      return
      end
      
      
      
      subroutine pio_user_error_wrong_length
     +     (s_len, sbr, ln_len, length_name, good, bad)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Input arguments.
      character sbr*(*), length_name*(*)
      integer s_len, ln_len, good, bad
      
      ier = PIO_USER_WRONG_LENGTH_ERROR
      
      em_len = 15 + s_len + 1 + 24 + ln_len + 1 + 10 + 1
     +     + 18 + ln_len + 1 + 10 + 1
      em_len = min(em_len, PIO_USER_MAX_ERROR_MESSAGE_LENGTH)
      
      write(error_msg, 1001) sbr(1:s_len),
     +     length_name(1:ln_len), good,
     +     length_name(1:ln_len), bad
      
 1001 format('fatal error in ', a, ':',
     +     ' waiting for a value of ', a, ' ', i10, ',',
     +     ' but found one of ', a, ' ', i10, '.')
      
      return
      end


      subroutine pio_user_error_too_large_length
     +     (s_len, sbr, ln_len, length_name, good, bad)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Input arguments.
      character sbr*(*), length_name*(*)
      integer s_len, ln_len, good, bad
      
      ier = PIO_USER_TOO_LARGE_LENGTH_ERROR
      
      em_len = 15 + s_len + 1 + 24 + ln_len + 9 + 10 + 1
     +     + 18 + ln_len + 1 + 10 + 1
      em_len = min(em_len, PIO_USER_MAX_ERROR_MESSAGE_LENGTH)
      
      write(error_msg, 1001) sbr(1:s_len),
     +     length_name(1:ln_len), good,
     +     length_name(1:ln_len), bad
      
 1001 format('fatal error in ', a, ':',
     +     ' waiting for a value of ', a, ' at most ', i10, ','
     +     ' but found one of ', a, ' ', i10, '.')
      
      return
      end


      subroutine pio_user_error_too_small_length
     +     (s_len, sbr, ln_len, length_name, good, bad)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Input arguments.
      character sbr*(*), length_name*(*)
      integer s_len, ln_len, good, bad
      
      ier = PIO_USER_TOO_SMALL_LENGTH_ERROR
      
      em_len = 15 + s_len + 1 + 24 + ln_len + 10 + 10 + 1
     +     + 18 + ln_len + 1 + 10 + 1
      em_len = min(em_len, PIO_USER_MAX_ERROR_MESSAGE_LENGTH)
      
      write(error_msg, 1001) sbr(1:s_len),
     +     length_name(1:ln_len), good,
     +     length_name(1:ln_len), bad
      
 1001 format('fatal error in ', a, ':',
     +     ' waiting for a value of ', a, ' at least ', i10, ','
     +     ' but found one of ', a, ' ', i10, '.')
      
      return
      end


      subroutine pio_user_set_debug_mode
      
      implicit none
      
      include 'pio_user_options_definition.fh'
      
      is_debug_mode_on = .True.
      is_report_mode_on = .True.
      
      return
      end


      subroutine pio_user_unset_debug_mode
      
      implicit none
      
      include 'pio_user_options_definition.fh'
      
      is_debug_mode_on = .False.
      
      return
      end


      logical function pio_user_get_debug_mode()
      
      implicit none
      
      include 'pio_user_options_definition.fh'
      
      pio_user_get_debug_mode = is_debug_mode_on
      
      return
      end


      subroutine pio_user_set_report_mode
      
      implicit none
      
      include 'pio_user_options_definition.fh'
      
      is_report_mode_on = .True.
      
      return
      end


      subroutine pio_user_unset_report_mode
      
      implicit none
      
      include 'pio_user_options_definition.fh'
      
      is_report_mode_on = .False.
      is_debug_mode_on = .False.
      
      return
      end


      logical function pio_user_get_report_mode()
      
      implicit none
      
      include 'pio_user_options_definition.fh'
      
      pio_user_get_report_mode = is_report_mode_on
      
      return
      end


      subroutine pio_user_debug_message(msg)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Local variable.
      character msg*(*)
      
C     External function.
      logical pio_user_get_debug_mode
      
      if (pio_user_get_debug_mode())
     +     write(PIO_USER_DEBUG, *) msg_prefix(1:mp_len), msg
      
      return
      end


      subroutine pio_user_report_message(msg)
      
      implicit none
      
      include 'pio_user_error_definition.fh'
      
C     Local variable.
      character msg*(*)
      
C     External function.
      logical pio_user_get_report_mode
      
      if (pio_user_get_report_mode())
     +     write(PIO_USER_REPORT, *) msg_prefix(1:mp_len), msg
      
      return
      end
