CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C                              Ref-indic                              C
C                                                                     C
C                        Refinement indicators                        C
C                                                                     C
C               EPI Pomdapi, INRIA Paris - Rocquencourt               C
C                                                                     C
C  Copyright (c) 2013-2014 INRIA.                                     C
C  Institut National de Recherche en Informatique et en Automatique.  C
C  All rights reserved. This file is distributed only by permission.  C
C                                                                     C
C  Hend Ben Ameur <hbenameur@yahoo.ca>                                C
C  Francois Clement <Francois.Clement@inria.fr>                       C
C  Pierre Weis <Pierre.Weis@inria.fr>                                 C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

C     $Id: init_scheme.f,v 1.6 2014/06/04 09:14:00 fclement Exp $

      subroutine init_scheme(ncells, ndS, S,
     +     ier, emsg_length, error_msg)
      
      implicit none

      integer SCHEME_DATA_UNIT
      parameter(SCHEME_DATA_UNIT=12)
      integer OUTPUT_UNIT
      parameter(OUTPUT_UNIT=18)
      
      include 'common.fh'
      
C     Output arguments.
      character*80 error_msg
      integer ncells, ndS, ier, emsg_length
      real*8 S(*)
      
C     Local variables.
      integer i, j, n
      real*8 rlongx, rlongy, duration, eps
      real*8 S1, q11, tf01, f01, f21, f1b1, f1h1
      
      ier = 0
      
C     File for all the monitoring outputs of the program.
      open(OUTPUT_UNIT,
     +     file='output', status='unknown',
     +     access='sequential', form='formatted', iostat=ier)
      if (ier .ne. 0) then
         emsg_length = 39
         error_msg = 'Unable to open file "output" for write.'
         return
      endif
      
C     File for all the parameter data of the program.
      open(SCHEME_DATA_UNIT,
     +     file='scheme_data', status='old',
     +     access='sequential', form='formatted', iostat=ier)
      if (ier .ne. 0) then
         emsg_length = 36
         error_msg = 'Unable to open file "scheme_data" for read.'
         return
      endif
      
C     Space discretization.

      read(SCHEME_DATA_UNIT,*) nx
      write(OUTPUT_UNIT,*) 'nx = ', nx
      read(SCHEME_DATA_UNIT,*) ny
      write(OUTPUT_UNIT,*) 'ny = ', ny
      ncells = nx*ny
      write(OUTPUT_UNIT,*) '=> ncells = ', ncells
      
      read(SCHEME_DATA_UNIT,*) rlongx
      write(OUTPUT_UNIT,*) 'rlongx = ', rlongx
      read(SCHEME_DATA_UNIT,*) rlongy
      write(OUTPUT_UNIT,*) 'rlongx = ', rlongx
      
      dx = rlongx / nx
      write(OUTPUT_UNIT, *) '=> dx = ', dx
      dy = rlongy / ny
      write(OUTPUT_UNIT, *) '=> dy = ', dy
      
C     Time discretization.
      
C     Stability condition
      eps = 1e-3
      dt = (1 - eps) * dx * dy
      write(OUTPUT_UNIT, *) '=> dt = ', dt
      
      read(SCHEME_DATA_UNIT,*) duration
      write(OUTPUT_UNIT,*) 'duration = ', duration
      
      nt = int(duration / dt + eps*eps)
      write(OUTPUT_UNIT, *) '=> nt = ', nt
      duration = nt * dt
      write(OUTPUT_UNIT, *) '=> duration = ', duration
      
      read(SCHEME_DATA_UNIT,*) theta
      write(OUTPUT_UNIT,*) 'theta = ', theta
      sigma = 1d0 - theta
      
C     Donnees de S,Q
      
      ndS = ncells
      read(SCHEME_DATA_UNIT,*) S1
      write(OUTPUT_UNIT,*) 'S1 = ', S1
      do i = 1, ncells
         S(i) = S1
      enddo
      
      read(SCHEME_DATA_UNIT,*) q11
      write(OUTPUT_UNIT,*) 'q11 = ', q11
      do n = 1,nt
         do i = 1,ncells
            q(i,n) = q11
         enddo
      enddo

c     Conditions initiales et conditions aux limites
      
      read(SCHEME_DATA_UNIT,*) tf01
      write(OUTPUT_UNIT,*) 'tf01 = ', tf01
      do i = 1,nx*(ny+1)+nx*ny
         tf0(i) = tf01
      enddo
      read(SCHEME_DATA_UNIT,*) f01
      write(OUTPUT_UNIT,*) 'f01 = ', f01
      do i = 1,nx*ny
         f0(i) = f01
      enddo
      
      read(SCHEME_DATA_UNIT,*) f21
      write(OUTPUT_UNIT,*) 'f21 = ', f21
      do j = 1,ny
         f2(i) = f21
      enddo
      read(SCHEME_DATA_UNIT,*) f1b1
      write(OUTPUT_UNIT,*) 'f1b1 = ', f1b1
      read(SCHEME_DATA_UNIT,*) f1h1
      write(OUTPUT_UNIT,*) 'f1h1 = ', f1h1
      do i = 1,nx
         f1b(i) = f1b1
         f1h(i+nx*ny) = f1h1
      enddo
      
      close(SCHEME_DATA_UNIT)
      
      return
      end
